@@ -2,10 +2,12 @@
 
 from time import sleep
 import logging
-import yaml
+from ruamel.yaml import YAML
 import click
 import paho.mqtt.client as mqtt
+
 from . import modbus_interface
+from . import version
 
 class mqtt_interface():
     def __init__(self, hostname, port, username, password, config_file, mqtt_topic_prefix):
@@ -109,10 +111,10 @@ class mqtt_interface():
         for register in self._get_registers_with('set_topic'):
             self._mqtt_client.subscribe(self.prefix+register['set_topic'])
             print("Subscribed to {}".format(self.prefix+register['set_topic']))
-        self._mqtt_client.publish(self.prefix+'modbus4mqtt', 'hi')
+        self._mqtt_client.publish(self.prefix+'modbus4mqtt', 'modbus4mqtt v{} connected.'.format(version.version))
 
-    def _on_disconnect(self, client, userdata, flags, rc):
-        logging.info("Disconnected")
+    def _on_disconnect(self, client, userdata, rc):
+        logging.warning("Disconnected from MQTT. Attempting to reconnect.")
 
     def _on_subscribe(self, client, userdata, mid, granted_qos):
         pass
@@ -146,7 +148,8 @@ class mqtt_interface():
             self._mb.set_value(register.get('table', 'holding'), register['address'], int(value), register.get('mask', 0xFFFF))
 
     def _load_modbus_config(self, path):
-        return yaml.load(open(path,'r').read(), Loader=yaml.FullLoader)
+        yaml=YAML(typ='safe')
+        return yaml.load(open(path,'r').read())
 
     def loop_forever(self):
         while True:
@@ -166,6 +169,7 @@ def main(hostname, port, username, password, config, mqtt_topic_prefix):
         format='%(asctime)s %(levelname)-8s %(message)s',
         level=logging.INFO,
         datefmt='%Y-%m-%d %H:%M:%S')
+    logging.info("Starting modbus4mqtt v{}".format(version.version))
     i = mqtt_interface(hostname, port, username, password, config, mqtt_topic_prefix)
     i.connect()
     i.loop_forever()
