@@ -78,7 +78,7 @@ class MQTTTests(unittest.TestCase):
                 mock_mqtt().connect.assert_called_with('kroopit', 1885, 60)
 
                 m._on_connect(None, None, None, rc=0)
-                mock_mqtt().publish.assert_called_with(MQTT_TOPIC_PREFIX+'/modbus4mqtt', 'hi')
+                mock_mqtt().publish.assert_called_with(MQTT_TOPIC_PREFIX+'/modbus4mqtt', 'modbus4mqtt v{} connected.'.format(modbus4mqtt.version.version))
                 mock_mqtt().subscribe.assert_called_with(MQTT_TOPIC_PREFIX+'/subscribe')
                 mock_mqtt().subscribe.assert_no_call(MQTT_TOPIC_PREFIX+'/publish')
 
@@ -101,7 +101,7 @@ class MQTTTests(unittest.TestCase):
                 mock_mqtt().connect.assert_called_with('kroopit', 1885, 60)
                 m._on_connect(None, None, None, rc=1)
                 # TODO implement some more thorough checks?
-                mock_mqtt().publish.assert_no_call(MQTT_TOPIC_PREFIX+'/modbus4mqtt', 'hi')
+                mock_mqtt().publish.assert_no_call(MQTT_TOPIC_PREFIX+'/modbus4mqtt', 'modbus4mqtt v{} connected.'.format(modbus4mqtt.version.version))
 
     def test_pub_on_change(self):
         with patch('paho.mqtt.client.Client') as mock_mqtt:
@@ -186,18 +186,21 @@ class MQTTTests(unittest.TestCase):
                 m.connect()
                 self.modbus_tables['holding'][1] = 1
                 self.modbus_tables['holding'][2] = 2
+                self.modbus_tables['holding'][3] = 1
                 m.poll()
 
                 mock_mqtt().publish.assert_any_call(MQTT_TOPIC_PREFIX+'/value_map_absent', 1, retain=False)
                 mock_mqtt().publish.assert_any_call(MQTT_TOPIC_PREFIX+'/value_map_present', 'b', retain=False)
+                mock_mqtt().publish.assert_any_call(MQTT_TOPIC_PREFIX+'/value_map_misinterpretation', 'on', retain=False)
                 mock_mqtt().publish.reset_mock()
 
                 # This value is outside the map, check it comes through in raw form
                 self.modbus_tables['holding'][2] = 3
+                self.modbus_tables['holding'][3] = 2
                 m.poll()
 
-                # print(mock_mqtt.mock_calls)
                 mock_mqtt().publish.assert_any_call(MQTT_TOPIC_PREFIX+'/value_map_present', 3, retain=False)
+                mock_mqtt().publish.assert_any_call(MQTT_TOPIC_PREFIX+'/value_map_misinterpretation', 'off', retain=False)
                 mock_mqtt().publish.reset_mock()
 
     def test_invalid_address(self):
